@@ -4,12 +4,12 @@ from os import makedirs
 from pathlib import Path
 from typing import List
 
+from xdg import xdg_data_home
+
 from blackcap.cluster.base import BaseCluster
 from blackcap.schemas.schedule import Schedule
 from blackcap.utils.cli_commands import call_cli
 
-from xdg import xdg_data_home
-
 
 class SlurmCluster(BaseCluster):
     """Slurm interface."""
@@ -25,7 +25,7 @@ class SlurmCluster(BaseCluster):
         job = schedule.job
         job_data_path: Path = (
             xdg_data_home() / "orchestra" / "demon" / "jobs" / str(job.job_id)
-        )  # noqa: E501
+        )
         makedirs((job_data_path / "out"), exist_ok=True)
         with open(job_data_path.joinpath("start.sh"), "w+") as f:
             f.write(job.script)
@@ -34,7 +34,7 @@ class SlurmCluster(BaseCluster):
                 f"""#! /bin/bash
                 conda activate orchestra
 
-                demon pub schedup --sched_id={schedule.schedule_id} --job_id={job.job_id} --status=RUNNING  # noqa: E501
+                demon pub schedup --sched_id={schedule.schedule_id} --job_id={job.job_id} --status=RUNNING  # noqa: B950
                 """
             )
         with open(job_data_path.joinpath("notify_ok.sh"), "w+") as f:
@@ -42,7 +42,7 @@ class SlurmCluster(BaseCluster):
                 f"""#! /bin/bash
                 conda activate orchestra
 
-                demon pub schedup --sched_id={schedule.schedule_id} --job_id={job.job_id} --status=COMPLETED  # noqa: E501
+                demon pub schedup --sched_id={schedule.schedule_id} --job_id={job.job_id} --status=COMPLETED  # noqa: B950
                 """
             )
         with open(job_data_path.joinpath("notify_not_ok.sh"), "w+") as f:
@@ -50,7 +50,7 @@ class SlurmCluster(BaseCluster):
                 f"""#! /bin/bash
                 conda activate orchestra
 
-                demon pub schedup --sched_id={schedule.schedule_id} --job_id={job.job_id} --status=FAILED  # noqa: E501
+                demon pub schedup --sched_id={schedule.schedule_id} --job_id={job.job_id} --status=FAILED  # noqa: B950
                 """
             )
 
@@ -66,11 +66,7 @@ class SlurmCluster(BaseCluster):
         job = schedule.job
         self.prepare_job(schedule)
         job_data_path: Path = (
-            xdg_data_home()
-            / "orchestra"
-            / "demon"
-            / "jobs"
-            / str(job.job_id)  # noqa: E501
+            xdg_data_home() / "orchestra" / "demon" / "jobs" / str(job.job_id)
         )
         job_script_path: Path = job_data_path / "start.sh"
         # notify_start_script_path: Path = job_data_path / "notify_start.sh"
