@@ -2,4 +2,4 @@
 
 from .executor import Executor  # noqa: F401
 from .flow import Flow, FlowExecError, FlowStatus, get_outer_function  # noqa: F401
-from .step import Prop, Step  # noqa: F401
+from .step import FuncProp, Prop, Step  # noqa: F401
