@@ -1,7 +1,9 @@
 """Base messenger class."""
 
 from abc import ABC, abstractclassmethod
-from typing import Callable, Dict, Optional
+from typing import Any, Callable, Dict, Optional
+
+from blackcap.schemas.message import Message
 
 
 class BaseMessenger(ABC):
@@ -14,7 +16,7 @@ class BaseMessenger(ABC):
     CONFIG_KEY_VAL = "GCP"
 
     @abstractclassmethod
-    def publish(self: "BaseMessenger", msg: Dict, topic_id: str) -> str:  # noqa: E501
+    def publish(self: "BaseMessenger", msg: Dict, topic_id: str) -> str:
         """Publish a msg.
 
         Args:
@@ -29,7 +31,7 @@ class BaseMessenger(ABC):
         callback: Callable,
         sub_id: str,
         timeout: Optional[float] = None,
-    ) -> None:  # noqa: E501
+    ) -> None:
         """Subscribe to a topic.
 
         Args:
@@ -38,3 +40,12 @@ class BaseMessenger(ABC):
             timeout (Union[float, None]): Time to wait for msgs. Defaults to None. # noqa: E501
         """
         pass
+
+    @abstractclassmethod
+    def parse_messenger_msg(self: "BaseMessenger", messenger_msg: Any) -> Message:
+        """Parse messenger msg to blackcap mesage schema.
+
+        Args:
+            messenger_msg (Any): Messenger specific message
+        """
+        pass
