@@ -1,9 +1,9 @@
 """Blackcap Auth PUT route schemas."""
-from typing import List
+
+from typing import Any, Dict, List, Union
 
 from blackcap.schemas.api.common import ResponseSchema
 from blackcap.schemas.user import User
-
 from pydantic import BaseModel
 
 
@@ -17,4 +17,4 @@ class AuthCredsUpdate(BaseModel):
 class AuthPOSTResponse(ResponseSchema):
     """User POST response schema."""
 
-    items: List[User]
+    items: Dict[str, List[Union[User, Any]]]
