@@ -9,7 +9,7 @@ from pydantic.types import UUID4
 class Cluster(BaseModel):
     """Cluster schema."""
 
-    cluster_id: Optional[UUID4]
+    cluster_id: UUID4
     name: str
     cluster_type: str
     status: str = "ONLINE"
