@@ -9,9 +9,9 @@ from pydantic.types import UUID4
 class Job(BaseModel):
     """Job schema."""
 
-    job_id: Optional[UUID4]
+    job_id: UUID4
     name: str
-    description: Optional[str]
+    description: str = ""
     job_type: str = ""
     specification: Dict = {}
     job_metadata: Dict = {}
